/* Blinker
   Copyright 2011-2014 Stefan Schuermans <stefan@blinkenarea.org>
   Copyleft GNU public license - http://www.gnu.org/copyleft/gpl.html
   a blinkenarea.org project */

#ifndef BLINKER_TRANSFORMER_H
#define BLINKER_TRANSFORMER_H

#include <string>

#include <BlinkenLib/BlinkenFrame.h>

#include "Directory.h"
#include "File.h"
#include "InStreamFile.h"
#include "Mgrs.h"
#include "Module.h"
#include "OutStreamFile.h"
#include "StreamRecv.h"
#include "Transform.h"
#include "TransformFile.h"

namespace Blinker {

/// a stream transformer (i.e. rotate or mirror)
class Transformer: public Module, public StreamRecv
{
public:
  /**
   * @brief constructor
   * @param[in] name module name
   * @param[in] mgrs managers
   * @param[in] dirBase base directory
   */
  Transformer(const std::string &name, Mgrs &mgrs, const Directory &dirBase);

  /// virtual destructor
  virtual ~Transformer();

private:
  /// copy constructor disabled
  Transformer(const Transformer &that);

  /// assignment operator disabled
  const Transformer & operator=(const Transformer &that);

public:
  /// check for update of configuration
  virtual void updateConfig();

  /**
   * @brief set current frame
   * @param[in] stream stream name
   * @param[in] pFrame current frame (NULL for none)
   */
  virtual void setFrame(const std::string &stream, stBlinkenFrame *pFrame);

protected:
  /// (re-)get transformation to apply
  void getTransform();

  /// send current frame to output stream
  void sendFrame();

  /**
   * @brief process frame
   * @param[in] pFrame frame to process (NULL for none)
   */
  void procFrame(stBlinkenFrame *pFrame);

protected:
  InStreamFile  m_fileInStream;  ///< input stream name file
  TransformFile m_fileTransform; ///< transformation file
  OutStreamFile m_fileOutStream; ///< output stream name file
}; // class Transformer

} // namespace Blinker

#endif // #ifndef BLINKER_TRANSFORMER_H

